<?php
if (!defined("WHMCS")) {
    die("This file cannot be accessed directly");
}

// Required function to define the module's details
function mybundlepay_MetaData()
{
    return array(
        'DisplayName' => 'MyBundlePay',
        'APIVersion' => '1.1',
        'TokenisedStorage' => false,
    );
}

// Configuration options for the admin panel
function mybundlepay_config()
{
    return array(
        'FriendlyName' => array(
            'Type' => 'System',
            'Value' => 'MyBundlePay',
        ),
        'secretKey' => array(
            'FriendlyName' => 'Secret Key',
            'Type' => 'text',
            'Size' => '64',
            'Default' => '',
            'Description' => 'Enter your MyBundlePay secret key here',
        ),
        'returnUrl' => array(
            'FriendlyName' => 'Return URL',
            'Type' => 'text',
            'Size' => '255',
            'Default' => '',
            'Description' => 'Enter the return URL after payment is completed.',
        ),
    );
}

// Function that processes the payment
function mybundlepay_link($params)
{
    // Gateway Configuration Parameters
    $secretKey = $params['secretKey'];
    $returnUrl = $params['returnUrl'];

    // Invoice Parameters
    $invoiceId = $params['invoiceid'];
    $amount = $params['amount']; // The payment amount in the invoice currency
    $currency = $params['currency'];

    // Client Parameters
    $clientEmail = $params['clientdetails']['email'];
    $clientFirstName = $params['clientdetails']['firstname'];
    $clientLastName = $params['clientdetails']['lastname'];

    // Generate a transaction reference
    $tx_ref = $invoiceId . '_' . time();

    // Create a payment link through the MyBundlePay API
    $postData = array(
        "amount" => $amount,
        "currency" => $currency,
        "email" => $clientEmail,
        "first_name" => $clientFirstName,
        "last_name" => $clientLastName,
        "return_url" => $returnUrl,
        "tx_ref" => $tx_ref,
        "customization" => array(
            "title" => "Invoice Payment",
            "description" => "Payment for invoice #" . $invoiceId,
            "logo" => "https://yourwebsite.com/logo.png"
        ),
        "meta" => array(
            "uuid" => $invoiceId,
            "response" => "Response"
        )
    );

    $curl = curl_init();
    curl_setopt_array($curl, array(
        CURLOPT_URL => "https://mybundlepay.com/ng/api/payment",
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_ENCODING => "",
        CURLOPT_MAXREDIRS => 10,
        CURLOPT_TIMEOUT => 0,
        CURLOPT_FOLLOWLOCATION => true,
        CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
        CURLOPT_CUSTOMREQUEST => "POST",
        CURLOPT_POSTFIELDS => json_encode($postData),
        CURLOPT_HTTPHEADER => array(
            "Accept: application/json",
            "Content-Type: application/json",
            "Authorization: Bearer " . $secretKey,
        ),
    ));

    $response = curl_exec($curl);
    curl_close($curl);
    $responseData = json_decode($response, true);

    if ($responseData['status'] === 'success') {
        $checkoutUrl = $responseData['data']['checkout_url'];
        // Redirect the user to the payment page
        $htmlOutput = '<form method="GET" action="' . $checkoutUrl . '">
                           <input type="submit" value="Pay Now" />
                       </form>';
    } else {
        $htmlOutput = 'Error creating payment link. Please contact support.';
    }

    return $htmlOutput;
}